@@ -18,8 +18,8 @@ mod ib;
 mod open;
 mod tinkoff;
 
-use std::collections::{HashMap, HashSet, BTreeMap, BTreeSet};
-use std::collections::hash_map::Entry;
+use std::cmp::Ordering;
+use std::collections::{HashMap, HashSet, BTreeMap, BTreeSet, hash_map::Entry};
 
 use log::warn;
 
@@ -60,7 +60,7 @@ pub struct BrokerStatement {
     pub period: (Date, Date),
 
     pub cash_assets: MultiCurrencyCashAccount,
-    pub historical_cash_assets: BTreeMap<Date, MultiCurrencyCashAccount>,
+    pub historical_assets: BTreeMap<Date, NetAssets>,
 
     pub fees: Vec<Fee>,
     pub cash_flows: Vec<CashFlow>,
@@ -159,7 +159,7 @@ impl BrokerStatement {
 
     fn new_empty_from(broker: BrokerInfo, statement: &PartialBrokerStatement) -> GenericResult<BrokerStatement> {
         let mut period = statement.get_period()?;
-        if statement.get_starting_assets()? {
+        if statement.get_has_starting_assets()? {
             return Err!(concat!(
                 "The first broker statement ({}) has a non-zero starting assets. ",
                 "Make sure that broker statements directory contains statements for all periods ",
@@ -174,7 +174,7 @@ impl BrokerStatement {
             period: period,
 
             cash_assets: MultiCurrencyCashAccount::new(),
-            historical_cash_assets: BTreeMap::new(),
+            historical_assets: BTreeMap::new(),
 
             fees: Vec::new(),
             cash_flows: Vec::new(),
@@ -286,12 +286,16 @@ impl BrokerStatement {
         if let Entry::Occupied(mut open_position) = self.open_positions.entry(symbol.to_owned()) {
             let available = open_position.get_mut();
 
-            if *available == quantity {
-                open_position.remove();
-            } else if *available > quantity {
-                *available = (*available - quantity).normalize();
-            } else {
-                return Err!("The portfolio has not enough open positions for {}", symbol);
+            match quantity.cmp(available) {
+                Ordering::Equal => {
+                    open_position.remove();
+                },
+                Ordering::Less => {
+                    *available = (*available - quantity).normalize();
+                },
+                Ordering::Greater => {
+                    return Err!("The portfolio has not enough open positions for {}", symbol);
+                },
             }
         } else {
             return Err!("The portfolio has no open {} position", symbol);
@@ -440,12 +444,11 @@ impl BrokerStatement {
         self.broker.statements_merging_strategy.validate(self.period, period)?;
         self.period.1 = period.1;
 
-        if let Some(cash_assets) = statement.cash_assets {
-            assert!(self.historical_cash_assets.insert(
-                self.last_date(), cash_assets.clone()
-            ).is_none());
+        if let partial::NetAssets{cash: Some(cash), other} = statement.assets {
+            self.cash_assets = cash.clone();
 
-            self.cash_assets = cash_assets;
+            let assets = NetAssets{cash, other};
+            assert!(self.historical_assets.insert(self.last_date(), assets).is_none());
         } else if last {
             return Err!("Unable to find any information about current cash assets");
         }
@@ -641,4 +644,9 @@ impl BrokerStatement {
 
         Ok(())
     }
+}
+
+pub struct NetAssets {
+    pub cash: MultiCurrencyCashAccount,
+    pub other: Option<Cash>, // Supported only for some brokers
 }
\ No newline at end of file
